pub fn is_deploy_helper_path(path: &Path) -> bool
Returns whether the path points to a deploy helper source generated by the preprocessor.
These sources only exist in the compiler input and are never written to disk.